@@ -25,6 +25,7 @@ from .qtgui import (
     QRadioButton,
     QSizePolicy,
     QVBoxLayout,
+    QWidget,
 )
 
 from mercurial import (
@@ -41,6 +42,19 @@ from . import (
     qtlib,
 )
 
+if hglib.TYPE_CHECKING:
+    from typing import (
+        Dict,
+        List,
+        Optional,
+        Text,
+    )
+
+    from . import (
+        thgrepo,
+    )
+
+
 WD_PARENT = _('= Working Directory Parent =')
 
 _ARCHIVE_TYPES = [
@@ -66,18 +80,20 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
     _archive_content_touched_since = 2
 
     def __init__(self, repoagent, rev, parent=None, minrev=None):
+        # type: (thgrepo.RepoAgent, Optional[Text], Optional[QWidget], Optional[Text]) -> None
         super(ArchiveWidget, self).__init__(parent)
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
         self._repoagent = repoagent
-        if minrev is None:
+        if not minrev:
             minrev = rev
             archive_since = False
         else:
             archive_since = True
 
         possibleroots = []
-        if minrev is not None:
-            parents = scmutil.revsymbol(self.repo, str(minrev)).parents()
+        if minrev:
+            parents = hglib.revsymbol(self.repo,
+                                      hglib.fromunicode(minrev)).parents()
             if parents:
                 for p in parents:
                     possibleroots.append(u'%d' % p.rev())
@@ -112,7 +128,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         self.rootrev_combo = QComboBox(self)
         self.rootrev_combo.setEditable(True)
         self.rootrev_combo.setSizeAdjustPolicy(QComboBox.AdjustToContents)
-        if minrev is not None:
+        if minrev:
             for text in possibleroots:
                 self.rootrev_combo.addItem(text)
             self.rootrev_combo.setCurrentIndex(0)
@@ -164,7 +180,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         for t in sorted(self.repo.tags(), reverse=True):
             self.rev_combo.addItem(hglib.tounicode(t))
         if rev:
-            text = hglib.tounicode(str(rev))
+            text = rev
             selectindex = self.rev_combo.findText(text)
             if selectindex >= 0:
                 self.rev_combo.setCurrentIndex(selectindex)
@@ -191,10 +207,12 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         return self._repoagent.rawRepo()
 
     def rev_combo_changed(self):
+        # type: () -> None
         self.subrepos_chk.setChecked(self.get_subrepos_present())
         self.update_path()
 
     def browse_clicked(self):
+        # type: () -> None
         """Select the destination directory or file"""
         dest = pycompat.unicode(self.dest_edit.text())
         if not os.path.exists(dest):
@@ -216,36 +234,45 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             self.update_path()
 
     def get_subrepos_present(self):
+        # type: () -> bool
         rev = self.get_selected_rev()
         try:
-            ctx = scmutil.revsymbol(self.repo, rev)
+            ctx = hglib.revsymbol(self.repo, rev)
         except (error.LookupError, error.RepoLookupError):
             return False
-        return '.hgsubstate' in ctx
+        return b'.hgsubstate' in ctx
 
     def get_selected_rev(self):
+        # type: () -> bytes
         rev = self.rev_combo.currentText()
         if rev == WD_PARENT:
-            rev = '.'
+            rev = b'.'
         else:
             rev = hglib.fromunicode(rev)
         return rev
 
     def get_selected_rootrev(self):
+        # type: () -> bytes
         rev = self.rootrev_combo.currentText()
         return hglib.fromunicode(rev)
 
     def get_selected_archive_type(self):
+        # type: () -> Dict[Text, Text]
         """Return a dictionary describing the selected archive type"""
         return _ARCHIVE_TYPES[self._typesradios.checkedId()]
 
     def update_path(self):
+        # type: () -> None
+
+        # pytype: disable=redundant-function-type-comment
         def remove_ext(path):
+            # type: (Text) -> Text
             for ext in ('.tar', '.tar.bz2', '.tar.gz', '.zip'):
                 if path.endswith(ext):
                     return path.replace(ext, '')
             return path
         def remove_rev(path):
+            # type: (Text) -> Text
             l = ''
             for i in pycompat.xrange(self.rev_combo.count() - 1):
                 l += pycompat.unicode(self.rev_combo.itemText(i))
@@ -258,12 +285,16 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
                     return path.replace(rev, '')
             return path
         def add_rev(path, rev):
+            # type: (Text, Text) -> Text
             return '%s_%s' % (path, rev)
         def add_ext(path):
+            # type: (Text) -> Text
             select = self.get_selected_archive_type()
             if select['type'] != 'files':
                 path += select['ext']
             return path
+        # pytype: enable=redundant-function-type-comment
+
         text = pycompat.unicode(self.rev_combo.currentText())
         if len(text) == 0:
             self.commandChanged.emit()
@@ -273,7 +304,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             text = wdrev
         else:
             try:
-                scmutil.revsymbol(self.repo, hglib.fromunicode(text))
+                hglib.revsymbol(self.repo, hglib.fromunicode(text))
             except (error.RepoError, error.LookupError):
                 self.commandChanged.emit()
                 return
@@ -288,6 +319,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
 
     @pyqtSlot()
     def compose_command(self):
+        # type: () -> List[Text]
         content = self.content_mode.checkedId()
         targetrev = hglib.tounicode(self.get_selected_rev())
         if content == self._archive_content_all_files:
@@ -309,6 +341,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         return cmdline
 
     def canRunCommand(self):
+        # type: () -> bool
         rev = self.get_selected_rev()
         if not rev or not self.dest_edit.text():
             return False
@@ -319,6 +352,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             return False
 
     def runCommand(self):
+        # type: () -> cmdcore.CmdSession
         # verify input
         type = self.get_selected_archive_type()['type']
         dest = pycompat.unicode(self.dest_edit.text())
@@ -353,6 +387,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
 
 
 def createArchiveDialog(repoagent, rev=None, parent=None, minrev=None):
+    # type: (thgrepo.RepoAgent, Optional[Text], Optional[QWidget], Optional[Text]) -> cmdui.CmdControlDialog
     dlg = cmdui.CmdControlDialog(parent)
     dlg.setWindowTitle(_('Archive - %s') % repoagent.displayName())
     dlg.setWindowIcon(qtlib.geticon('hg-archive'))
