@@ -247,7 +247,7 @@ class ExceptionCatcher(QObject):
         def _handleWakeup(self):
             # here Python signal handler will be invoked
             self._wakeupsn.setEnabled(False)
-            rfd = self._wakeupsn.socket()
+            rfd = int(self._wakeupsn.socket())
             try:
                 os.read(rfd, 1)
             except OSError as inst:
@@ -437,6 +437,8 @@ class QtRunner(QObject):
         self._mainapp.setOrganizationName('TortoiseHg')
         self._mainapp.setOrganizationDomain('tortoisehg.org')
         self._mainapp.setApplicationVersion(thgversion.version())
+        if hasattr(self._mainapp, 'setDesktopFileName'):  # introduced in Qt 5.7
+            self._mainapp.setDesktopFileName('thg.desktop')
         self._fixlibrarypaths()
         self._installtranslator()
         QFont.insertSubstitutions('monospace', ['monaco', 'courier new'])
