@@ -797,6 +797,7 @@ class ThgFont(QObject):
 _fontdefaults = {
     'fontcomment': 'monospace,10',
     'fontdiff': 'monospace,10',
+    'fonteditor': 'monospace,10',
     'fontlog': 'monospace,10',
     'fontoutputlog': 'sans,8'
 }
@@ -879,10 +880,10 @@ class CustomPrompt(QMessageBox):
         super(CustomPrompt, self).keyPressEvent(event)
 
 class ChoicePrompt(QDialog):
-    def __init__(self, title, message, parent, choices, default=None,
-                 esc=None, files=None):
+    def __init__(self, title, message, parent, choices, default=None):
+        # type: (Text, Text, QWidget, List[Text], Optional[Text]) -> None
         QDialog.__init__(self, parent)
-        self.setWindowTitle(hglib.tounicode(title))
+        self.setWindowTitle(title)
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
 
         self.box = QHBoxLayout()
@@ -895,7 +896,7 @@ class ChoicePrompt(QDialog):
 
         self.choice_combo = combo = QComboBox()
         self.choices = choices
-        combo.addItems([hglib.tounicode(item) for item in choices])
+        combo.addItems(choices)
         if default:
             try:
                 combo.setCurrentIndex(choices.index(default))
@@ -916,6 +917,7 @@ class ChoicePrompt(QDialog):
         self.setLayout(self.box)
 
     def run(self):
+        # type: () -> Optional[Text]
         if self.exec_():
             return self.choices[self.choice_combo.currentIndex()]
         return None
