@@ -1122,6 +1122,9 @@ INFO = (
     _fi(_('Diff Font'), 'tortoisehg.fontdiff', genFontEdit,
         _('Font used to display text differences. Default: monospace 10'),
         globalonly=True),
+    _fi(_('Editor Font'), 'tortoisehg.fonteditor', genFontEdit,
+        _('Font used for the text editor. Default: monospace 10'),
+        globalonly=True),
     _fi(_('ChangeLog Font'), 'tortoisehg.fontlog', genFontEdit,
         _('Font used to display changelog data. Default: monospace 10'),
         globalonly=True),
