@@ -28,7 +28,7 @@ locale_path = os.path.join(bin_path, 'locale')
 icon_path = os.path.join(bin_path, 'icons')
 
 enc = sys.getfilesystemencoding()
-if enc:
+if enc and sys.version_info[0] == 2:
     bin_path = bin_path.encode(enc)
     license_path = license_path.encode(enc)
     locale_path = locale_path.encode(enc)
